@@ -39,7 +39,7 @@ background = '#fff'
 odd_plot_background = '#fff'
 candle_bull_color = '#26a69a'
 candle_bear_color = '#ef5350'
-candle_bull_body_color = '#26a69a'
+candle_bull_body_color = candle_bull_color
 volume_bull_color = '#92d2cc'
 volume_bear_color = '#f7a9a7'
 volume_bull_body_color = volume_bull_color
